==> responsibleai-0.12.1.tar.gz: responsibleai-0.12.1/tests/explainer_manager_validator.py <==
# Copyright (c) Microsoft Corporation
# Licensed under the MIT License.

from responsibleai.exceptions import UserConfigValidationException
import pytest
from responsibleai._internal.constants import ManagerNames, ListProperties
from responsibleai import ModelTask

LIGHTGBM_METHOD = 'mimic.lightgbm'


def setup_explainer(model_analysis, add_explainer=True):
    if add_explainer:
        if model_analysis.model is None:
            with pytest.raises(
                    UserConfigValidationException,
                    match='Model is required for model explanations'):
                model_analysis.explainer.add()
            return
        else:
            model_analysis.explainer.add()
        # Validate calling add multiple times prints a warning
        with pytest.warns(UserWarning):
            model_analysis.explainer.add()
    model_analysis.explainer.compute()


def validate_explainer(model_analysis, X_train, X_test, classes):
    if model_analysis.model is None:
        return
    explanations = model_analysis.explainer.get()
    assert isinstance(explanations, list)
    assert len(explanations) == 1
    explanation = explanations[0]
    num_cols = len(X_train.columns) - 1
    if classes is not None:
        assert len(explanation.local_importance_values) == len(classes)
        assert len(explanation.local_importance_values[0]) == len(X_test)
        assert len(explanation.local_importance_values[0][0]) == num_cols
    else:
        assert len(explanation.local_importance_values) == len(X_test)
        assert len(explanation.local_importance_values[0]) == num_cols

    properties = model_analysis.explainer.list()
    assert properties[ListProperties.MANAGER_TYPE] == ManagerNames.EXPLAINER
    assert 'id' in properties
    assert properties['method'] == LIGHTGBM_METHOD
    if classes is not None:
        assert properties['model_task'] == ModelTask.CLASSIFICATION
    else:
        assert properties['model_task'] == ModelTask.REGRESSION
    assert properties['model_type'] is None
    assert properties['is_raw'] is False
    assert properties['is_engineered'] is False

==> responsibleai-0.18.2.tar.gz: responsibleai-0.18.2/tests/explainer_manager_validator.py <==
# Copyright (c) Microsoft Corporation
# Licensed under the MIT License.

import pytest

from responsibleai import ModelTask
from responsibleai._internal.constants import ListProperties, ManagerNames
from responsibleai.exceptions import UserConfigValidationException

LIGHTGBM_METHOD = 'mimic.lightgbm'


def setup_explainer(rai_insights, add_explainer=True):
    if add_explainer:
        if rai_insights.model is None:
            with pytest.raises(
                    UserConfigValidationException,
                    match='Model is required for model explanations'):
                rai_insights.explainer.add()
            return
        else:
            rai_insights.explainer.add()
        # Validate calling add multiple times prints a warning
        with pytest.warns(
            UserWarning,
            match="DUPLICATE-EXPLAINER-CONFIG: Ignoring. "
                  "Explanation has already been added, "
                  "currently limited to one explainer type."):
            rai_insights.explainer.add()
    rai_insights.explainer.compute()


def validate_explainer(rai_insights, X_train, X_test, classes):
    if rai_insights.model is None:
        return
    explanations = rai_insights.explainer.get()
    assert isinstance(explanations, list)
    assert len(explanations) == 1
    explanation = explanations[0]
    num_cols = len(X_train.columns) - 1
    if classes is not None:
        assert len(explanation.local_importance_values) == len(classes)
        assert len(explanation.local_importance_values[0]) == len(X_test)
        assert len(explanation.local_importance_values[0][0]) == num_cols
    else:
        assert len(explanation.local_importance_values) == len(X_test)
        assert len(explanation.local_importance_values[0]) == num_cols

    properties = rai_insights.explainer.list()
    assert properties[ListProperties.MANAGER_TYPE] == ManagerNames.EXPLAINER
    assert 'id' in properties
    assert properties['method'] == LIGHTGBM_METHOD
    if classes is not None:
        assert properties['model_task'] == ModelTask.CLASSIFICATION
    else:
        assert properties['model_task'] == ModelTask.REGRESSION
    assert properties['model_type'] is None
    assert properties['is_raw'] is False
    assert properties['is_engineered'] is False

    # Check the internal state of explainer manager
    assert rai_insights.explainer._is_added
    assert rai_insights.explainer._is_run
